@@ -4,7 +4,7 @@ import typing as t
 
 
 def _bitbucket_pipelines_url() -> str:
-    return "https://bitbucket.org/atlassianlabs/intellij-bitbucket-references-plugin/raw/master/src/main/resources/schemas/bitbucket-pipelines.schema.json"  # noqa: E501
+    return "https://api.bitbucket.org/schemas/pipelines-configuration"
 
 
 def _githubusercontent_url(owner: str, repo: str, ref: str, path: str) -> str:
@@ -76,7 +76,9 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         },
     },
     "circle-ci": {
-        "url": "https://json.schemastore.org/circleciconfig.json",
+        "url": _githubusercontent_url(
+            "CircleCI-Public", "circleci-yaml-language-server", "main", "schema.json"
+        ),
         "hook_config": {
             "name": "Validate CircleCI config",
             "description": (
@@ -98,6 +100,16 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types_or": ["json", "yaml"],
         },
     },
+    "codecov": {
+        "url": "https://www.schemastore.org/codecov.json",
+        "hook_config": {
+            "name": "Validate Codecov config",
+            "files": [
+                r"^((\.github|dev)/)?\.?codecov\.ya?ml$",
+            ],
+            "types": "yaml",
+        },
+    },
     "compose-spec": {
         "url": _githubusercontent_url(
             "compose-spec",
@@ -141,6 +153,26 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types": "yaml",
         },
     },
+    "github-issue-config": {
+        "url": "https://www.schemastore.org/github-issue-config.json",
+        "hook_config": {
+            "name": "Validate GitHub issue config",
+            "files": [
+                r"^\.github/ISSUE_TEMPLATE/config\.yml$",
+            ],
+            "types": "yaml",
+        },
+    },
+    "github-issue-forms": {
+        "url": "https://www.schemastore.org/github-issue-forms.json",
+        "hook_config": {
+            "name": "Validate GitHub issue forms",
+            "files": [
+                r"^\.github/ISSUE_TEMPLATE/(?!config\.ya?ml$).+$",
+            ],
+            "types": "yaml",
+        },
+    },
     "github-workflows": {
         "url": "https://json.schemastore.org/github-workflow",
         "hook_config": {
@@ -162,7 +194,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
                 "--regex-variant",
                 "nonunicode",
             ],
-            "files": r"^.*\.gitlab-ci\.yml$",
+            "files": r"^.*\.gitlab-ci\.(yml|yaml)$",
             "types": "yaml",
         },
     },
@@ -208,8 +240,7 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
         "hook_config": {
             "name": "Validate ReadTheDocs Config",
             "description": (
-                "Validate ReadTheDocs config against the schema "
-                "provided by ReadTheDocs"
+                "Validate ReadTheDocs config against the schema provided by ReadTheDocs"
             ),
             "files": r"^\.readthedocs\.(yml|yaml)$",
             "types": "yaml",
